/**
 * Le formateur qui écrit les résultats dans un format adapté pour la console.
 */
export default class ConsoleFormatter extends Formatter {
    /**
     * Crée un formateur.
     *
     * @param {Level}    level                    Le niveau de sévérité minimum
     *                                            des notifications affichées.
     * @param {Object}   options                  Les options du formateur.
     * @param {Writable} [options.writer]         Le flux où écrire les
     *                                            résultats.
     * @param {boolean}  [options.showZeroNotice] La marque indiquant s'il faut
     *                                            afficher les fichiers sans
     *                                            notification.
     * @param {boolean}  [options.showNoChecked]  Le marque indiquant s'il faut
     *                                            afficher les fichiers
     *                                            non-analysés.
     */
    constructor(level: Level, options: {
        writer?: Writable;
        showZeroNotice?: boolean;
        showNoChecked?: boolean;
    });
    #private;
}
export type Writable = import("node:stream").Writable;
export type Level = import("../../types/level.d.ts").default;
export type Location = import("../../types/location.d.ts").default;
export type Notice = import("../../types/notice.d.ts").default;
export type Severity = import("../../types/severity.d.ts").default;
import Formatter from "./formatter.js";
